============
servicepytan
============


.. image:: https://img.shields.io/pypi/v/servicepytan.svg
        :target: https://pypi.python.org/pypi/servicepytan

.. image:: https://img.shields.io/travis/elliotpalmer/servicepytan.svg
        :target: https://travis-ci.com/elliotpalmer/servicepytan

.. image:: https://readthedocs.org/projects/servicepytan/badge/?version=latest
        :target: https://servicepytan.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python Library to make it easier to interact with the ServiceTitan API v2


* Free software: MIT license
* Documentation: https://servicepytan.readthedocs.io.


Features
--------

* Simple Syntax for getting data from standard RESTful endpoints from ServiceTitan
* Ability to extract custom report data and automatically make calls for additional data

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
